@@ -10,7 +10,7 @@ except ImportError:
     cwd = Path(__file__).parent.parent
     sys.path.append(cwd.as_posix())
 
-from itkdb_gtk import dbGtkUtils, ITkDBlogin, ITkDButils
+from itkdb_gtk import dbGtkUtils, ITkDBlogin, ITkDButils, QRScanner
 import gi
 
 gi.require_version("Gtk", "3.0")
@@ -77,7 +77,7 @@ class ReceiveShipments(dbGtkUtils.ITkDBWindow):
         self.set_border_width(10)
 
         # intercept keyboard
-        dbGtkUtils.setup_scanner(self.get_qrcode)
+        self.scanner = QRScanner.QRScanner(self.get_qrcode)
 
         # Prepare HeaderBar
         self.hb.props.title = "{} shipments".format(self.recipient)
@@ -183,9 +183,8 @@ class ReceiveShipments(dbGtkUtils.ITkDBWindow):
 
         return scrolled
 
-    def get_qrcode(self, fd, state, reader):
+    def get_qrcode(self, txt):
         """Gets data from QR scanner."""
-        txt = dbGtkUtils.scanner_get_line(reader)
         self.write_message("{}\n".format(txt))
 
         if txt.find("J-SD") == 0:
