@@ -11,7 +11,7 @@ except ImportError:
     cwd = Path(__file__).parent.parent
     sys.path.append(cwd.as_posix())
 
-from itkdb_gtk import dbGtkUtils, ITkDBlogin, ITkDButils
+from itkdb_gtk import dbGtkUtils, ITkDBlogin, ITkDButils, QRScanner
 from itkdb_gtk.ShowComments import ShowComments
 from itkdb_gtk.ShowDefects import ShowDefects
 from itkdb_gtk.UploadTest import create_json_data_editor
@@ -120,8 +120,7 @@ class PanelVisualInspection(dbGtkUtils.ITkDBWindow):
 
 
         self.show_all()
-
-        dbGtkUtils.setup_scanner(self.get_qrcode)
+        self.scanner = QRScanner.QRScanner(self.get_qrcode)
 
     def on_global_image(self, *args):
         """We choose the global image."""
@@ -553,9 +552,8 @@ class PanelVisualInspection(dbGtkUtils.ITkDBWindow):
             lv_iter = model.iter_next(lv_iter)
 
 
-    def get_qrcode(self, fd, state, reader):
+    def get_qrcode(self,txt):
         """Read SN from scanner."""
-        txt = dbGtkUtils.scanner_get_line(reader)
         self.write_message("SN: {}\n".format(txt))
         self.SN_ready(txt, self.SN.widget)
 
