@@ -687,8 +687,11 @@ class UploadMultipleTests(dbGtkUtils.ITkDBWindow):
             rc = ITkDButils.upload_test(self.session, payload, values[TestList.Attachments], check_runNumber=True)
             if rc:
                 ipos = rc.find("The following details may help:")
-                msg = rc[ipos:]
-                dbGtkUtils.complain("Failed uploading test {}-{}".format(payload["component"], payload["testType"]))
+                if ipos>=0:
+                    msg = rc[ipos:]
+                else:
+                    msg = rc
+                dbGtkUtils.complain("Failed uploading test {}-{}\n".format(payload["component"], payload["testType"]), msg)
                 self.write_message("Failed uploading test {}-{}\n{}\n".format(payload["component"], payload["testType"], msg))
                 nbad += 1
 
@@ -702,7 +705,7 @@ class UploadMultipleTests(dbGtkUtils.ITkDBWindow):
                 model.remove(past_iter)
 
         if nbad>0:
-            dbGtkUtils.complain("Failed to upload all tests", "{} test had errors.\nThey are left in the ListView.")
+            dbGtkUtils.complain("Failed to upload some tests", "{}/{} tests had errors.\nThey are left in the ListView.".format(nbad, ngood))
         else:
             dbGtkUtils.complain("All {} tests uploaded succesfully".format(ngood))
 
