@@ -1,6 +1,6 @@
 """ itkdb-gtk python module
 """
-__version__ = "0.17.0"
+__version__ = "0.19.0"
 
 
 def dash_board():
@@ -55,3 +55,8 @@ def visualInspection():
     """Visual inspection of Modules/Sensors."""
     from .VisualInspection import main
     main()
+
+def findDBComponent():
+    """Find object from QR or bar code"""
+    from .findComponent import main
+    main()
