@@ -8,7 +8,6 @@ from collections.abc import Iterable
 from copy import deepcopy
 from datetime import datetime
 import webbrowser
-import serial
 
 import dateutil.parser
 import numpy as np
@@ -29,34 +28,6 @@ except ImportError:
 from itkdb_gtk import ITkDButils
 
 
-def setup_scanner(callback):
-    """Setup scanner and callback function."""
-    for fnam in ["/dev/ttyACM0", "/dev/cu.usbmodemS_N_G19F204881"]:
-        P = pathlib.Path(fnam)
-        if P.exists():
-            rdr = serial.Serial(fnam, 9600)
-            GLib.unix_fd_add_full(
-                GLib.PRIORITY_DEFAULT,
-                rdr.fileno(),
-                GLib.IOCondition.IN,
-                callback,
-                rdr,
-            )
-            break
-
-def scanner_get_line(reader):
-    """Reads a line from serial."""
-    available = reader.in_waiting
-    while True:
-        delta = reader.in_waiting - available
-        if not delta:
-            break
-
-    # Get data from serial device passed in via
-    data = reader.read_until(expected='\r', size=reader.in_waiting).strip()
-    txt = data.decode('utf-8')
-    return txt
-
 def parse_date(txt):
     """Parse a date."""
     try:
